#!-PERL-
# addtextrect.pl
#
# THIS FILE IS COPYRIGHT 1994 BY TELENOR RESEARCH, NORWAY
#
#                    ALL RIGHTS RESERVED.
#
# For rights granted to the public see the COPYRIGHT file
#
# Programming : Jon Stephenson von Tetzchner
  
# This script is part of the fm2html package.
  
# Parameters: infile, outfile, list of textrects
  
$\ = "\n";		# set output record separator
$, = " ";		# set output field separator
$* = 0;			# set single line pattern matching

select( STDERR );	# all error messages go to stderr
$| = 1;			# make stderr unbuffered

$FALSE = 0;
$TRUE  = 1;


sub escape	# take string, insert backslash before special characters
{
  local( $_ ) = @_;
  s|([\.\+\?\*\'\"\(\)])|\\$1|g;
  $_;
}

sub basename	# take pathname, strip leading directories and optional suffix
{
  local( $_, $suffix ) = @_;
  m|/|o && s|^.*/([^/]*)$|$1|;
  $suffix = &escape( $suffix );
  s|(.*)$suffix|$1|;
  $_;
}


local( $prog ) = &basename( $0 );
local( $usage ) = "Usage: $prog infile outfile textrectid...";

local( $infile ) = shift;
local( $outfile ) = shift;

local( @textrectids );
local( $numtextrectids ) = 0;
local( $found ) = 0;
local( $numfound ) = 0;
local( $textflow ) = "";
local( $fig ) = 0;

while ( @ARGV )
{
  $textrectids[$numtextrectids] = shift;
  $numtextrectids += 1;
}

$infile .= ".mif";

open( INFILE, "<$infile" ) ||
  die "$prog: Could not open input file \"$infile\"... exiting";
open( OUTFILE, ">>$outfile" ) ||
  die "$prog: Could not open output file \"$outfile\"... exiting";

PRELOOP:
while ( <INFILE> )
{
  if ( m|^<TextFlow | ) 
  {
    $textflow = $_;
    last PRELOOP;
  }
}

LOOP:
while( <INFILE> ) 
{
  local( $textline ) = $_;

  if ( $textline =~ m|^<TextFlow | || $textflow ne "" ) 
    { $textflow .= "$textline"; }

  if ( $textline =~ m|<TextRectID| && ! $fig ) 
  {
    local( $temp ) = 0;

    while ( $temp < $numtextrectids && ! $found )
    {
      if ( $textline =~ m|<TextRectID $textrectids[$temp]>| )
        { $found = 1; }

      $temp += 1;
    }
  } 
  elsif ( $textline =~ m|<PgfTag \`figur\'>| ) 
  {
    $fig = 1;
  } 
  elsif ( $textline =~ m|^> # end of TextFlow| ) 
  {
    if ( $found ) 
    {
      print OUTFILE "$textflow";
      $found = 0;
      undef $textflow;
      $textflow = "";
      $numfound++;

      if ( $numfound == $numtextrectids )
        { last LOOP; }
    } 
    else 
    {
      $fig = 0;
      undef $textflow;
      $textflow = "";
    }
  }
}
  
close( OUTFILE );
close( INFILE );
